Improve this Doc View Source

Use `$anchorScrollProvider` to disable automatic scrolling whenever $location.hash() changes.

## Methods

- ###

  `disableAutoScrolling();`

  By default, $anchorScroll() will automatically detect changes to $location.hash() and scroll to the element matching the new hash.
  Use this method to disable automatic scrolling.

  If automatic scrolling is disabled, one must explicitly call $anchorScroll() in order to scroll to the element related to the current hash.